package com.fs.qw.service.impl;

import com.fs.qw.domain.QwFriendCustomerList;
import com.fs.qw.mapper.QwFriendCustomerListMapper;
import com.fs.qw.service.IQwFriendCustomerListService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企业朋友圈 发送到客户朋友里 成功的客户数据Service业务层处理
 *
 * @author fs
 * @date 2024-09-18
 */
@Service
public class QwFriendCustomerListServiceImpl implements IQwFriendCustomerListService
{
    @Autowired
    private QwFriendCustomerListMapper qwFriendCustomerListMapper;

    /**
     * 查询企业朋友圈 发送到客户朋友里 成功的客户数据
     *
     * @param id 企业朋友圈 发送到客户朋友里 成功的客户数据主键
     * @return 企业朋友圈 发送到客户朋友里 成功的客户数据
     */
    @Override
    public QwFriendCustomerList selectQwFriendCustomerListById(Long id)
    {
        return qwFriendCustomerListMapper.selectQwFriendCustomerListById(id);
    }

    /**
     * 查询企业朋友圈 发送到客户朋友里 成功的客户数据列表
     *
     * @param qwFriendCustomerList 企业朋友圈 发送到客户朋友里 成功的客户数据
     * @return 企业朋友圈 发送到客户朋友里 成功的客户数据
     */
    @Override
    public List<QwFriendCustomerList> selectQwFriendCustomerListList(QwFriendCustomerList qwFriendCustomerList)
    {
        return qwFriendCustomerListMapper.selectQwFriendCustomerListList(qwFriendCustomerList);
    }

    /**
     * 新增企业朋友圈 发送到客户朋友里 成功的客户数据
     *
     * @param qwFriendCustomerList 企业朋友圈 发送到客户朋友里 成功的客户数据
     * @return 结果
     */
    @Override
    public int insertQwFriendCustomerList(QwFriendCustomerList qwFriendCustomerList)
    {
        return qwFriendCustomerListMapper.insertQwFriendCustomerList(qwFriendCustomerList);
    }

    /**
     * 修改企业朋友圈 发送到客户朋友里 成功的客户数据
     *
     * @param qwFriendCustomerList 企业朋友圈 发送到客户朋友里 成功的客户数据
     * @return 结果
     */
    @Override
    public int updateQwFriendCustomerList(QwFriendCustomerList qwFriendCustomerList)
    {
        return qwFriendCustomerListMapper.updateQwFriendCustomerList(qwFriendCustomerList);
    }

    /**
     * 批量删除企业朋友圈 发送到客户朋友里 成功的客户数据
     *
     * @param ids 需要删除的企业朋友圈 发送到客户朋友里 成功的客户数据主键
     * @return 结果
     */
    @Override
    public int deleteQwFriendCustomerListByIds(Long[] ids)
    {
        return qwFriendCustomerListMapper.deleteQwFriendCustomerListByIds(ids);
    }

    /**
     * 删除企业朋友圈 发送到客户朋友里 成功的客户数据信息
     *
     * @param id 企业朋友圈 发送到客户朋友里 成功的客户数据主键
     * @return 结果
     */
    @Override
    public int deleteQwFriendCustomerListById(Long id)
    {
        return qwFriendCustomerListMapper.deleteQwFriendCustomerListById(id);
    }
}
